@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 ##
-## Copyright (C) 2003-2007, Marcelo E. Magallon <mmagallo[]debian org>
-## Copyright (C) 2003-2007, Milan Ikits <milan ikits[]ieee org>
+## Copyright (C) 2002-2008, Marcelo E. Magallon <mmagallo[]debian org>
+## Copyright (C) 2002-2008, Milan Ikits <milan ikits[]ieee org>
 ##
 ## This program is distributed under the terms and conditions of the GNU
 ## General Public License Version 2 as published by the Free Software
@@ -22,13 +22,13 @@ if (@ARGV)
 	my $curexttype = "";
 	foreach my $ext (sort @extlist)
 	{
-		my ($extname, $exturl, $types, $tokens, $functions, $exacts) = parse_ext($ext);
+		my ($extname, $exturl, $extstring, $reuse, $types, $tokens, $functions, $exacts) = parse_ext($ext);
 		my $exttype = $extname;
-		$exttype =~ s/(W*?)GL(X*?)_(.*?_)(.*)/$3/;
+		$exttype =~ s/(W?E?)GL(X?)_(.*?_)(.*)/$3/;
 		my $extrem = $extname;
-		$extrem =~ s/(W*?)GL(X*?)_(.*?_)(.*)/$4/;
+		$extrem =~ s/(W?E?)GL(X?)_(.*?_)(.*)/$4/;
 		my $extvar = $extname;
-		$extvar =~ s/(W*)GL(X*)_/$1GL$2EW_/;
+		$extvar =~ s/(W?E?)GL(X?)_/$1GL$2EW_/;
 		if(!($exttype =~ $curexttype))
 		{
 			if(length($curexttype) > 0)
